package com.fjhx.wms.service.stock.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.common.utils.Assert;
import com.fjhx.wms.entity.stock.dto.StockCheckRegisterDto;
import com.fjhx.wms.entity.stock.dto.StockCheckRegisterSelectDto;
import com.fjhx.wms.entity.stock.po.Stock;
import com.fjhx.wms.entity.stock.po.StockCheckRegister;
import com.fjhx.wms.entity.stock.vo.StockCheckRegisterVo;
import com.fjhx.wms.mapper.stock.StockCheckRegisterMapper;
import com.fjhx.wms.service.stock.StockCheckRegisterService;
import com.fjhx.wms.service.stock.StockService;
import com.ruoyi.common.utils.wrapper.IWrapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 库存盘点登记 服务实现类
 * </p>
 *
 * @author
 * @since 2024-03-26
 */
@Service
public class StockCheckRegisterServiceImpl extends ServiceImpl<StockCheckRegisterMapper, StockCheckRegister> implements StockCheckRegisterService {

    @Autowired
    private StockService stockService;

    @Override
    public List<StockCheckRegisterVo> getList(StockCheckRegisterSelectDto dto) {
        IWrapper<StockCheckRegister> wrapper = getWrapper();
        wrapper.eq("scr", StockCheckRegister::getStockId, dto.getStockId());
        wrapper.eq("scr", StockCheckRegister::getWarehouseId, dto.getWarehouseId());
        List<StockCheckRegisterVo> list = this.getList(wrapper);
        return list;
    }

    @Override
    public List<StockCheckRegisterVo> getList(@Param("ew") IWrapper<StockCheckRegister> wrapper) {
        wrapper.orderByDesc("scr", StockCheckRegister::getCreateTime);
        wrapper.orderByDesc("scr", StockCheckRegister::getId);
        List<StockCheckRegisterVo> list = this.baseMapper.getList(wrapper);
        return list;
    }

    @Override
    public Page<StockCheckRegisterVo> getPage(StockCheckRegisterSelectDto dto) {
        IWrapper<StockCheckRegister> wrapper = getWrapper();
        wrapper.orderByDesc("scr", StockCheckRegister::getId);
        Page<StockCheckRegisterVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }

    @Override
    public StockCheckRegisterVo detail(Long id) {
        StockCheckRegister StockCheckRegister = this.getById(id);
        StockCheckRegisterVo result = BeanUtil.toBean(StockCheckRegister, StockCheckRegisterVo.class);
        return result;
    }

    @Override
    public void add(StockCheckRegisterDto stockCheckRegisterDto) {
        Assert.notEmpty(stockCheckRegisterDto.getCheckQuantity(), "盘点数量不能为空！");

        Stock stock = stockService.getById(stockCheckRegisterDto.getStockId());
        Assert.notEmpty(stock, "查询不到库存信息！");
        stockCheckRegisterDto.setWarehouseId(stock.getWarehouseId());
        stockCheckRegisterDto.setProductId(stock.getProductId());
        this.save(stockCheckRegisterDto);
    }

    @Override
    public void edit(StockCheckRegisterDto stockCheckRegisterDto) {
        this.updateById(stockCheckRegisterDto);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

}
